==> refcodes-servicebus-2.0.4-sources.jar: org/refcodes/servicebus/NoMatchingServiceRuntimeException.java <==
package org.refcodes.servicebus;

import org.refcodes.servicebus.ServiceBusRuntimeException.ServiceBusServiceMatcherRuntimeException;

/**
 * This exception is thrown whenever a service cannot be unambiguously
 * distinguished from another service because a matcher was not strict enough to
 * identify just one service.
 */
public class NoMatchingServiceRuntimeException extends ServiceBusServiceMatcherRuntimeException {

	private static final long serialVersionUID = 1L;

	// /////////////////////////////////////////////////////////////////////////
	// CONSTRUCTORS:
	// /////////////////////////////////////////////////////////////////////////

	/**
	 * Instantiates a new no matching service runtime exception.
	 *
	 * @param aServiceMatcher the service matcher
	 * @param aMessage the message
	 * @param aErrorCode the error code
	 */
	public NoMatchingServiceRuntimeException( ServiceMatcher<?> aServiceMatcher, String aMessage, String aErrorCode ) {
		super( aServiceMatcher, aMessage, aErrorCode );
	}

	/**
	 * Instantiates a new no matching service runtime exception.
	 *
	 * @param aServiceMatcher the service matcher
	 * @param aMessage the message
	 * @param aCause the cause
	 * @param aErrorCode the error code
	 */
	public NoMatchingServiceRuntimeException( ServiceMatcher<?> aServiceMatcher, String aMessage, Throwable aCause, String aErrorCode ) {
		super( aServiceMatcher, aMessage, aCause, aErrorCode );
	}

	/**
	 * Instantiates a new no matching service runtime exception.
	 *
	 * @param aServiceMatcher the service matcher
	 * @param message the message
	 * @param cause the cause
	 */
	public NoMatchingServiceRuntimeException( ServiceMatcher<?> aServiceMatcher, String message, Throwable cause ) {
		super( aServiceMatcher, message, cause );
	}

	/**
	 * Instantiates a new no matching service runtime exception.
	 *
	 * @param aServiceMatcher the service matcher
	 * @param message the message
	 */
	public NoMatchingServiceRuntimeException( ServiceMatcher<?> aServiceMatcher, String message ) {
		super( aServiceMatcher, message );
	}

	/**
	 * Instantiates a new no matching service runtime exception.
	 *
	 * @param aServiceMatcher the service matcher
	 * @param aCause the cause
	 * @param aErrorCode the error code
	 */
	public NoMatchingServiceRuntimeException( ServiceMatcher<?> aServiceMatcher, Throwable aCause, String aErrorCode ) {
		super( aServiceMatcher, aCause, aErrorCode );
	}

	/**
	 * Instantiates a new no matching service runtime exception.
	 *
	 * @param aServiceMatcher the service matcher
	 * @param cause the cause
	 */
	public NoMatchingServiceRuntimeException( ServiceMatcher<?> aServiceMatcher, Throwable cause ) {
		super( aServiceMatcher, cause );
	}

}

==> refcodes-servicebus-3.1.2-sources.jar: org/refcodes/servicebus/NoMatchingServiceRuntimeException.java <==
package org.refcodes.servicebus;

import org.refcodes.servicebus.ServiceBusRuntimeException.ServiceBusServiceMatcherRuntimeException;

/**
 * This exception is thrown whenever a service cannot be unambiguously
 * distinguished from another service because a matcher was not strict enough to
 * identify just one service.
 */
public class NoMatchingServiceRuntimeException extends ServiceBusServiceMatcherRuntimeException {

	private static final long serialVersionUID = 1L;

	// /////////////////////////////////////////////////////////////////////////
	// CONSTRUCTORS:
	// /////////////////////////////////////////////////////////////////////////

	/**
	 * Instantiates a new no matching service runtime exception.
	 *
	 * @param aServiceMatcher the service matcher
	 * @param aMessage The aMessage describing this exception.
	 * @param aErrorCode The error code identifying this exception.
	 */
	public NoMatchingServiceRuntimeException( ServiceMatcher<?> aServiceMatcher, String aMessage, String aErrorCode ) {
		super( aServiceMatcher, aMessage, aErrorCode );
	}

	/**
	 * Instantiates a new no matching service runtime exception.
	 *
	 * @param aServiceMatcher the service matcher
	 * @param aMessage The aMessage describing this exception.
	 * @param aCause The {@link Throwable} ({@link Exception}) causing this
	 *        exception.
	 * @param aErrorCode The error code identifying this exception.
	 */
	public NoMatchingServiceRuntimeException( ServiceMatcher<?> aServiceMatcher, String aMessage, Throwable aCause, String aErrorCode ) {
		super( aServiceMatcher, aMessage, aCause, aErrorCode );
	}

	/**
	 * Instantiates a new no matching service runtime exception.
	 *
	 * @param aServiceMatcher the service matcher
	 * @param aMessage The aMessage describing this exception.
	 * @param aCause The {@link Throwable} ({@link Exception}) causing this
	 *        exception.
	 */
	public NoMatchingServiceRuntimeException( ServiceMatcher<?> aServiceMatcher, String aMessage, Throwable aCause ) {
		super( aServiceMatcher, aMessage, aCause );
	}

	/**
	 * Instantiates a new no matching service runtime exception.
	 *
	 * @param aServiceMatcher the service matcher
	 * @param aMessage The aMessage describing this exception.
	 */
	public NoMatchingServiceRuntimeException( ServiceMatcher<?> aServiceMatcher, String aMessage ) {
		super( aServiceMatcher, aMessage );
	}

	/**
	 * Instantiates a new no matching service runtime exception.
	 *
	 * @param aServiceMatcher the service matcher
	 * @param aCause The {@link Throwable} ({@link Exception}) causing this
	 *        exception.
	 * @param aErrorCode The error code identifying this exception.
	 */
	public NoMatchingServiceRuntimeException( ServiceMatcher<?> aServiceMatcher, Throwable aCause, String aErrorCode ) {
		super( aServiceMatcher, aCause, aErrorCode );
	}

	/**
	 * Instantiates a new no matching service runtime exception.
	 *
	 * @param aServiceMatcher the service matcher
	 * @param aCause The {@link Throwable} ({@link Exception}) causing this
	 *        exception.
	 */
	public NoMatchingServiceRuntimeException( ServiceMatcher<?> aServiceMatcher, Throwable aCause ) {
		super( aServiceMatcher, aCause );
	}

}
